package org.kde.koala;
import org.kde.qt.*;


/** {@link KFileDialog} emits these signals */
public interface KFileDialogSignals {

/** 
 The OK button was pressed. This signal is only emitted if
 {@link KFileDialog#slotOk} is not replaced.
     
*/
	void okClicked();

/** 
 The Try button was pressed. This signal is only emitted if
 {@link KFileDialog#slotTry} is not replaced.
     
*/
	void tryClicked();

/** 
 The Yes button was pressed. This signal is only emitted if
 {@link KFileDialog#slotYes} is not replaced.
     
*/
	void yesClicked();
	void destroyed( QObject obj );

/** 
 The No button was pressed. This signal is only emitted if
 {@link KFileDialog#slotNo} is not replaced.
     
*/
	void noClicked();

/** 
 The Apply button was pressed. This signal is only emitted if
 {@link KFileDialog#slotApply} is not replaced.
     
*/
	void applyClicked();

/** 
 The Close button was pressed. This signal is only emitted if
 {@link KFileDialog#slotClose} is not replaced.
     
*/
	void closeClicked();

/** 
 The User3 button was pressed. This signal is only emitted if
 {@link KFileDialog#slotUser3} is not replaced.
     
*/
	void user3Clicked();

/** 
 Emitted when the user hilights one or more files in multiselection mode.

 Note: {@link KFileDialog#fileHighlighted} or {@link KFileDialog#fileSelected} are <em>not</em>
 emitted in multiselection mode. You may use selectedItems() to
 ask for the current highlighted items.

*/
	void selectionChanged();

/** 
 Emitted when the margin size and/or spacing size
 have changed.

 Use {@link KFileDialog#marginHint} and  {@link KFileDialog#spacingHint} in your slot
 to get the new values.
     
*/
	void layoutHintChanged();

/** 
 A page is about to be shown.
     
*/
	void aboutToShowPage( QWidget page );

/** 
 The dialog has finished.

 A dialog emits finished after a user clicks a button that ends
 the dialog.

 This signal is also emitted when you call {@link KFileDialog#hide}

 If you have stored a pointer to the
 dialog do <em>not</em> try to delete the pointer in the slot that is
 connected to this signal.

 You should use {@link KFileDialog#delayedDestruct} instead.
     
*/
	void finished();

/** 
 The detailsWidget is about to get shown. This is your last chance
 to call setDetailsWidget if you haven't done so yet.
     
*/
	void aboutToShowDetails();

/** 
 Do not use this signal. Is is kept for compatibility reasons.
 Use {@link KFileDialog#applyClicked} instead.
     
*/
	void apply();

/** 
 The User2 button was pressed. This signal is only emitted if
 {@link KFileDialog#slotUser2} is not replaced.
     
*/
	void user2Clicked();

/** 
 The Cancel button was pressed. This signal is only emitted if
 {@link KFileDialog#slotCancel} is not replaced.
     
*/
	void cancelClicked();

/** 
 The Default button was pressed. This signal is only emitted if
 {@link KFileDialog#slotDefault} is not replaced.
     
*/
	void defaultClicked();

/** 
 The User1 button was pressed. This signal is only emitted if
 {@link KFileDialog#slotUser1} is not replaced.
     
*/
	void user1Clicked();

/** 
 The dialog is about to be hidden.

 A dialog is hidden after a user clicks a button that ends
 the dialog or when the user switches to another desktop or
 minimizes the dialog.
     
*/
	void hidden();

/** 
 Emitted when the filter changed, i.e. the user entered an own filter
 or chose one of the predefined set via {@link KFileDialog#setFilter}.

*/
	void filterChanged( String filter );

/** 
 The background tile has changed.
     
*/
	void backgroundChanged();

/** 
 The Help button was pressed. This signal is only emitted if
 {@link KFileDialog#slotHelp} is not replaced.
     
*/
	void helpClicked();
}

